@@ -14,7 +14,6 @@ from typing import Any, Awaitable, Callable, Dict, List, Optional, Tuple, Type,
 import gvcode
 import shortuuid
 import vcode as mod_vcode
-from CodeConvert import CodeConvert as cc
 from redis import StrictRedis
 from redis.client import bool_ok
 from redis.exceptions import DataError, ResponseError, WatchError
@@ -42,20 +41,6 @@ KEY_PREFIX = 'r:'  # Prefix of redis-extensions used key
 WARNING_LOG = '``{0}`` used, may be very very very slow when keys\' amount very large'  # ``r.keys()`` and ``r.scan_iter()`` not support use
 
 
-POLL_QUEUE_CONTINUE_FLAG = True
-
-
-# Signal Handler
-def sigintHandler(signum, frame):
-    global POLL_QUEUE_CONTINUE_FLAG
-    POLL_QUEUE_CONTINUE_FLAG = False
-
-
-# signal.SIGKILL, `KILL -9`, unblockable
-for signum in [signal.SIGHUP, signal.SIGINT, signal.SIGTERM, signal.SIGTSTP]:
-    signal.signal(signum, sigintHandler)
-
-
 # Get the local ip
 def get_network_ip() -> str:
     try:
@@ -69,7 +54,7 @@ def get_network_ip() -> str:
     return ip
 
 
-class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
+class RedisExtensions(BaseRedisExpires, StrictRedis):
     """
     Extension of [redis-py](https://github.com/andymccurdy/redis-py)'s StrictRedis.
 
@@ -80,8 +65,9 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         self.rate = 10000000000000  # 10 ** 13,
         self.max_timestamp = 9999999999999
         self.timezone = kwargs.pop('timezone', None)
+        self.poll_queue_continue_flag = True
         tc.__init__(timezone=self.timezone)
-        super(StrictRedisExtensions, self).__init__(*args, **kwargs)
+        super(RedisExtensions, self).__init__(*args, **kwargs)
 
     def __str(self, x: Any) -> Union[str, bytes]:
         if isinstance(x, int):
@@ -398,6 +384,18 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         self.release_lock(name, locked)
         return item
 
+    def blpopv(self, keys: List, timeout: Optional[int] = 0) -> ResponseListT:
+        kv = self.blpop(keys, timeout)
+        if not kv:
+            return None
+        return kv[-1]
+
+    def brpopv(self, keys: List, timeout: Optional[int] = 0) -> ResponseListT:
+        kv = self.brpop(keys, timeout)
+        if not kv:
+            return None
+        return kv[-1]
+
     # Sets Section
     def delete_sadd(self, name: str, *values: FieldT) -> Tuple[ResponseIntT, ResponseT]:
         """
@@ -719,21 +717,33 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         mapping = {k: json.dumps(v, **self.__json_params(cls, json_params)) for (k, v) in mapping.items()}
         return self.hmset(name, mapping)
 
-    def hget_json(self, name: str, key: str, default: str = '{}') -> Dict[str, Any]:
+    def hget_json(self, name: str, key: str, default: str = '{}') -> ResponseJSON:
         return json.loads(self.hget(name, key) or default)
 
-    def hmget_json(self, name: str, keys: List, default: str = '{}', *args: List) -> List[Dict[str, Any]]:
+    def hget_list(self, name: str, key: str) -> List:
+        return self.hget_json(name, key, default='[]')
+
+    def hmget_json(self, name: str, keys: List, default: str = '{}', *args: List) -> List[ResponseJSON]:
         vals = self.hmget(name, keys, *args)
         return [json.loads(v or default) for v in vals]
 
-    def hvals_json(self, name: str, default: str = '{}') -> List[Dict[str, Any]]:
+    def hmget_list(self, name: str, keys: List, *args: List) -> List[List]:
+        return self.hmget_json(name, keys, default='[]', *args)
+
+    def hvals_json(self, name: str, default: str = '{}') -> List[ResponseJSON]:
         vals = self.hvals(name)
         return [json.loads(v or default) for v in vals]
 
+    def hvals_list(self, name: str) -> List[List]:
+        return self.hvals_json(name, default='[]')
+
     def hgetall_json(self, name: str, default: str = '{}') -> Dict[str, Any]:
         kvs = self.hgetall(name)
         return {k: json.loads(v or default) for (k, v) in kvs.items()}
 
+    def hgetall_list(self, name: str) -> Dict[str, Any]:
+        return self.hgetall_json(name, default='[]')
+
     def lpush_json(self, name: str, value: EncodableT, cls: Optional[Type[json.JSONDecoder]] = None, json_params: Dict[str, Any] = None):
         return self.lpush(name, json.dumps(value, **self.__json_params(cls, json_params)))
 
@@ -1122,7 +1132,7 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
                 logger.warning('Gvcode not found, exec gvcode_add or gvcode_refresh first')
         b64str, vcode = gvcode.get('b64str', ''), gvcode.get('vcode', '')
         self.setex(self.__gvcode_key(name), time, vcode)
-        return '{0}{1}'.format('data:image/png;base64,' if data_uri_scheme else '', cc.Convert2Utf8(b64str))
+        return '{0}{1}'.format('data:image/png;base64,' if data_uri_scheme else '', b64str)
 
     def gvcode_exists(self, name: str, code: str, ignore_blank: bool = True) -> bool:
         return (self.get(self.__gvcode_key(name)) or '').lower() == self.__final_code(code, ignore_blank=ignore_blank)
@@ -1183,6 +1193,10 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         self.release_poll_queue_lock(delayed, final_logger=final_logger)
         final_logger.info('>>> Release item lock end')
 
+    # Signal Handler
+    def __signal_handler(self, signum, frame):
+        self.poll_queue_continue_flag = False
+
     def poll_queue(self, callbacks: Dict[str, Callable] = {}, delayed: str = KEY_PREFIX + 'delayed:default', enable_auto_zrem: bool = False, enable_queue: bool = False, enable_process_lock: bool = False, process_lock_key: Optional[str] = None, release_lock_when_launch: bool = True, release_lock_eth0_inet_addr: Optional[str] = None, release_lock_when_error: bool = True, delayed_logger: Optional[logging.Logger] = None, unlocked_warning_func: Optional[Callable] = None):
         """
         Consumer of delay execute.
@@ -1201,12 +1215,12 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
 
         ``release_lock_eth0_inet_addr`` indicates eth0 inet addr, which can release lock when ``release_lock_when_launch``.
 
-        ``release_lock_key`` indicates acquire lock key when ``release_lock_when_launch``.
-
-        ``release_lock_key_expire`` indicates expire time of ``release_lock_key``.
-
         ``release_lock_when_error`` indicates whether release lock when error or not.
         """
+        # signal.SIGKILL, `KILL -9`, unblockable
+        for signum in [signal.SIGHUP, signal.SIGINT, signal.SIGTERM, signal.SIGTSTP]:
+            signal.signal(signum, self.__signal_handler)
+
         callbacks = {k: self.__callable_func(v) for k, v in callbacks.items()}
         callbacks = {k: v for k, v in callbacks.items() if v}
 
@@ -1220,7 +1234,7 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         self.__release_lock_when_launch(release_lock_when_launch, release_lock_eth0_inet_addr, final_process_lock_key, delayed, final_logger)
 
         process_lock = None
-        while POLL_QUEUE_CONTINUE_FLAG:
+        while self.poll_queue_continue_flag:
             if enable_process_lock:
                 # Release process lock
                 if process_lock:
@@ -1328,6 +1342,7 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
     lpushex = lpush_ex
     lrangeex = lrange_ex
     sortedpop = sorted_pop
+    bpopv = blpopv
     deletesadd = delete_sadd
     multispop = multi_spop
     srandshuffle = srandmembershuffle = srandmember_shuffle
@@ -1350,18 +1365,22 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
     hvalsstr = hvals_str
     hgetallstr = hgetall_str
     # JSON
-    setlist = set_list = setjson = set_json
-    setexlist = setex_list = setexjson = setex_json
-    setnxlist = setnx_list = setnxjson = setnx_json
-    getjson = get_json
+    setlist = set_list = setdict = set_dict = setjson = set_json
+    setexlist = setex_list = setexdict = setex_dict = setexjson = setex_json
+    setnxlist = setnx_list = setnxdict = setnx_dict = setnxjson = setnx_json
+    getdict = get_dict = getjson = get_json
     getlist = get_list
-    hsetjson = hset_json
-    hsetnxjson = hsetnx_json
-    hmsetjson = hmset_json
-    hgetjson = hget_json
-    hmgetjson = hmget_json
-    hvalsjson = hvals_json
-    hgetalljson = hgetall_json
+    hsetlist = hset_list = hsetdict = hset_dict = hsetjson = hset_json
+    hsetnxlist = hsetnx_list = hsetnxdict = hsetnx_dict = hsetnxjson = hsetnx_json
+    hmsetlist = hmset_list = hmsetdict = hmset_dict = hmsetjson = hmset_json
+    hgetdict = hget_dict = hgetjson = hget_json
+    hgetlist = hget_list
+    hmgetdict = hmget_dict = hmgetjson = hmget_json
+    hmgetlist = hmget_list
+    hvalsdict = hvals_dict = hvalsjson = hvals_json
+    hvalslist = hvals_list
+    hgetalldict = hgetall_dict = hgetalljson = hgetall_json
+    hgetalllist = hgetall_list
 
     lpushjson = pushjson = push_json = lpush_json
     rpushjson = rpush_json
@@ -1392,3 +1411,6 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
     dellpush = del_lpush = delpush = del_push = delete_lpush
     delrpush = del_rpush = delete_rpush
     delsadd = del_sadd = delete_sadd
+
+
+StrictRedisExtensions = RedisExtensions
